summaryrefslogtreecommitdiffstats
path: root/lib/kformula/errorelement.cc
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kformula/errorelement.cc')
-rw-r--r--lib/kformula/errorelement.cc18
1 files changed, 9 insertions, 9 deletions
diff --git a/lib/kformula/errorelement.cc b/lib/kformula/errorelement.cc
index 0bf80237..c63cf09c 100644
--- a/lib/kformula/errorelement.cc
+++ b/lib/kformula/errorelement.cc
@@ -28,24 +28,24 @@ ErrorElement::ErrorElement( BasicElement* tqparent ) : SequenceElement( tqparent
/**
* Draws the whole element including its tqchildren.
* The `tqparentOrigin' is the point this element's tqparent starts.
* We can use our tqparentPosition to get our own origin then.
*/
void ErrorElement::draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& tqparentOrigin )
+ const LuPixelPoint& parentOrigin )
{
- LuPixelPoint myPos( tqparentOrigin.x()+getX(), tqparentOrigin.y()+getY() );
+ LuPixelPoint myPos( parentOrigin.x()+getX(), parentOrigin.y()+getY() );
- painter.fillRect( context.tqlayoutUnitToPixelX( myPos.x() ),
- context.tqlayoutUnitToPixelY( myPos.y() ),
- context.tqlayoutUnitToPixelX( getWidth() ),
- context.tqlayoutUnitToPixelY( getHeight() ),
+ painter.fillRect( context.layoutUnitToPixelX( myPos.x() ),
+ context.layoutUnitToPixelY( myPos.y() ),
+ context.layoutUnitToPixelX( getWidth() ),
+ context.layoutUnitToPixelY( getHeight() ),
context.getErrorColor() );
- inherited::draw( painter, r, context, tstyle, istyle, style, tqparentOrigin );
+ inherited::draw( painter, r, context, tstyle, istyle, style, parentOrigin );
}
KFORMULA_NAMESPACE_END
@@ -28,24 +28,24 @@ ErrorElement::ErrorElement( BasicElement* tqparent ) : SequenceElement( tqparent
/**
* Draws the whole element including its tqchildren.
- * The `tqparentOrigin' is the point this element's tqparent starts.
- * We can use our tqparentPosition to get our own origin then.
+ * The `parentOrigin' is the point this element's tqparent starts.
+ * We can use our parentPosition to get our own origin then.
*/
void ErrorElement::draw( TQPainter& painter, const LuPixelRect& r,